%define anolis_release 3

%bcond_without gui
%bcond_with default_editor
%bcond_with libsodium_crypt

%global data_vimdir %{_datadir}/%{name}/%{vimdir}
%global data_dir %{_datadir}/%{name}

%if %{?WITH_SELINUX:0}%{!?WITH_SELINUX:1}
%define WITH_SELINUX 1
%endif

%if %{with gui}
%define desktop_file 1
%else
%define desktop_file 0
%endif

%if %{desktop_file}
%define desktop_file_utils_version 0.2.93
%endif

%define withnetbeans 1

%define withvimspell 0
%define withhunspell 0
%define withruby 0
%define withlua 1

%define baseversion 9.0
%define vimdir vim90

%define patchlevel 2092

Name: vim
Summary: Vim - the ubiquitous text editor
Version: %{baseversion}.%{patchlevel}
Release: %{anolis_release}%{?dist}
Epoch: 3
License: Vim and MIT
URL:     http://www.vim.org/
Source0: https://github.com/vim/vim/archive/refs/tags/v%{version}.tar.gz
Source1: virc
Source2: vimrc
Source3: gvim16.png
Source4: gvim32.png
Source5: gvim48.png
Source6: gvim64.png
Source7: spec-template.new
Source8: macros.vim
Source9: vim-default-editor.sh
Source10: vim-default-editor.csh
Source11: vim-default-editor.fish
Source12: view_wrapper
Source13: vi_wrapper

Patch0001: 1001-vim-8.0-copy-paste.patch

#CVE-2024-22667
#https://github.com/vim/vim/commit/b39b240c386a5a29241415541f1c99e2e6b8ce47
Patch0002: 1002-stack-buffer-overflow-in-option-callback-functions.patch

BuildRequires: autoconf gcc glibc-gconv-extra make
BuildRequires: gettext gpm-devel libacl-devel
BuildRequires: ncurses-devel python3-devel
BuildRequires: perl-devel perl-generators perl(ExtUtils::Embed) perl(ExtUtils::ParseXS)

%if %{desktop_file}
BuildRequires: desktop-file-utils >= %{desktop_file_utils_version}
Requires: desktop-file-utils
%endif

%if %{WITH_SELINUX}
BuildRequires: libselinux-devel
%endif

%if %{with libsodium_crypt}
BuildRequires: libsodium-devel
%endif

%if %{withlua}
BuildRequires: lua-devel
%endif

%if %{withruby}
BuildRequires: ruby ruby-devel
%endif

%description
Vim is a highly configurable text editor built to enable efficient
text editing. It is an improved version of the vi editor distributed
with most UNIX systems. Vim is often called a "programmer's editor,"
and so useful for programming that many consider it an entire IDE. It's
not just for programmers, though. Vim is perfect for all kinds of text
editing, from composing email to editing configuration files.

Despite what the above comic suggests, Vim can be configured to work in
a very simple (Notepad-like) way, called evim or Easy Vim.

Vim isn't an editor designed to hold its users' hands. It is a tool,
the use of which must be learned. Vim isn't a word processor. Although it
can display text with various forms of highlighting and formatting, it isn't
there to provide WYSIWYG editing of typeset documents.
(It is great for editing TeX, though.)


%package common
Summary: The common files needed by any version of the VIM editor
Requires: %{name}-data = %{EVR}
Requires: %{name}-filesystem
Conflicts: %{name}-minimal < %{epoch}:9.0

%description common
Vim-common is a package that provides common files for the Vim editor.
These files include documentation, syntax highlighting, and other configuration
files. It is a necessary package to install if you want to use Vim on your system.
Vim-common is typically installed alongside the Vim editor, which is a highly
configurable and powerful text editor that is popular among developers and system
administrators. If wanting the vim-enhanced or vim-X11, you also need to install
the vim-common package.

%package spell
Summary: The dictionaries for spell checking. This package is optional
Requires: vim-common = %{EVR}

%description spell
Vim-spell is a package for the Vim editor that provides spell-checking
functionality. It includes a dictionary of words that Vim can use to
check the spelling of a document, as well as commands for adding and
removing words from the dictionary. With Vim-spell, you can easily identify
and correct spelling errors in your documents, making it a valuable tool
for writers, editors, and anyone who works with text. Vim-spell is typically
installed as a plugin or extension for the Vim editor and can be enabled
or disabled as needed.

%package minimal
Summary: A minimal version of the VIM editor
Obsoletes: %{name}-wrappers < 2:9.0
Provides: vi
Provides: %{_bindir}/vi
Requires: %{name}-data = %{EVR}
Conflicts: %{name}-common < %{epoch}:9.0
Conflicts: %{name}-wrappers < 2:9.0

%description minimal
Vim-minimal is a stripped-down version of the Vim editor, designed to provide only
the most essential features and functionality. It is designed for users who prefer
a more lightweight and streamlined text editor, without the additional features and
plugins that can sometimes clutter the interface and slow down performance.

Vim-minimal typically comes with a minimal set of plugins and configuration files,
allowing users to customize the editor to their specific needs. Despite its minimal
design, Vim-minimal still includes many of the core features of the Vim editor,
such as syntax highlighting, multiple buffers, and powerful search and replace functionality.

Overall, Vim-minimal is a great choice for users who want a fast and efficient text
editor without all the bells and whistles of a full-featured IDE.

%package enhanced
Summary: A version of the VIM editor which includes recent enhancements
Provides: %{name}
Provides: %{_bindir}/mergetool
Provides: %{_bindir}/%{name}
Requires: %{name}-common = %{EVR}
Requires: which
Provides: bundled(libvterm)
Conflicts: vim-wrappers < 2:9.0
%if %{withlua}
Suggests: lua-libs
%endif

Suggests: python3
Suggests: python3-libs
Suggests: perl-devel

%if %{withruby}
Suggests: ruby
Suggests: ruby-libs
%endif

%description enhanced
Vim-enhanced is an enhanced version of the Vim editor that includes additional
features and functionality. It is designed to provide more advanced editing
capabilities than the standard version of Vim, making it a popular choice
among developers and power users. Overall, Vim-enhanced is a great choice for
users who require advanced editing capabilities and want to customize their
editor with a wide range of plugins and extensions. However, it may not be the
best choice for users who prefer a more minimalistic or lightweight approach
to text editing.

%package filesystem
Summary: VIM filesystem layout
BuildArch: noarch

%Description filesystem
This package provides some directories which are required by other
packages that add vim files, p.e.  additional syntax files or filetypes.

%if %{with gui}
%package X11
Summary: The VIM version of the vi editor for the X Window System - GVim
BuildRequires: gtk3-devel libICE-devel libSM-devel libX11-devel libXpm-devel
BuildRequires: libXt-devel libappstream-glib libcanberra-devel

Provides: %{_bindir}/mergetool
Provides: %{_bindir}/gvim
Provides: gvim
Requires: gtk3
Requires: hicolor-icon-theme
Requires: libattr >= 2.4
Requires: %{name}-common = %{EVR}
%if %{withlua}
Suggests: lua-libs
%endif

Suggests: python3
Suggests: perl-devel
Suggests: python3-libs

%if %{withruby}
Suggests: ruby
Suggests: ruby-libs
%endif

%description X11
When it comes to Vim, X11 allows for the use of Vim in a graphical environment,
rather than a pure text-only console. This means that Vim can be run in a terminal
emulator window, where it can take advantage of the windowing system's features,
such as window resizing and copy/paste functionality.

Using Vim in an X11 environment can also provide access to additional features,
such as syntax highlighting and mouse support, which may not be available in a
standard terminal environment. Overall, using Vim in an X11 environment can provide
a more user-friendly and feature-rich experience, making it a popular choice among
developers and power users.
%endif

%package data
Summary: Shared data for Vi and Vim
BuildArch: noarch
Conflicts: %{name}-filesystem < 2:9.0
Conflicts: %{name}-common < 2:9.0
Conflicts: %{name}-minimal < 2:9.0

%description data
The subpackage is used for shipping files and directories, which need to be
shared between vim-minimal and vim-common packages.

%if %{with default_editor}
%package default-editor
Summary: Set vim as the default editor
BuildArch: noarch
Conflicts: nano-default-editor < 5.3-3
Provides: system-default-editor
Requires: vim-enhanced
Conflicts: system-default-editor

%description default-editor
This subpackage contains files needed to set Vim as the default editor.
%endif

%package doc
Summary:        Documentation files for %{name}
Requires:       vim-common = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1 -n vim-%{version}

%{__chmod} -x runtime/tools/mve.awk

perl -pi -e "s,bin/nawk,bin/awk,g" runtime/tools/mve.awk

%build
cd src
autoconf

export CFLAGS="%{optflags} -D_GNU_SOURCE -D_FILE_OFFSET_BITS=64 -D_FORTIFY_SOURCE=2"
export CXXFLAGS="%{optflags} -D_GNU_SOURCE -D_FILE_OFFSET_BITS=64 -D_FORTIFY_SOURCE=2"

cp -f os_unix.h os_unix.h.save

perl -pi -e "s/vimrc/virc/"  os_unix.h
%configure CFLAGS="${CFLAGS} -DSYS_VIMRC_FILE='\"/etc/virc\"'" --prefix=%{_prefix} --with-features=small --with-x=no \
  --enable-multibyte --disable-netbeans \
%if %{WITH_SELINUX}
  --enable-selinux \
%else
  --disable-selinux \
%endif
  --disable-pythoninterp --disable-perlinterp --disable-tclinterp --with-tlib=ncurses --enable-gui=no --disable-gpm --exec-prefix=/ \
  --with-compiledby="<os@lists.openanolis.cn>" --with-modified-by="<os@lists.openanolis.cn>" --enable-fail-if-missing \
  --disable-canberra --disable-libsodium

%make_build
cp vim minimal-vim
make clean

mv -f os_unix.h.save os_unix.h

%if %{with gui}

%configure CFLAGS="${CFLAGS} -DSYS_VIMRC_FILE='\"/etc/vimrc\"'" \
  --with-features=huge --enable-python3interp=dynamic --enable-perlinterp=dynamic \
  --disable-tclinterp --with-x=yes --enable-xim --enable-multibyte --with-tlib=ncurses \
  --enable-gtk3-check --enable-gui=gtk3 --with-compiledby="<os@lists.openanolis.cn>" --enable-cscope \
  --with-modified-by="<os@lists.openanolis.cn>" \
  %if %{withnetbeans}
  --enable-netbeans \
  %else
  --disable-netbeans \
  %endif
  %if %{WITH_SELINUX}
  --enable-selinux \
  %else
  --disable-selinux \
  %endif
  %if %{withruby}
  --enable-rubyinterp=dynamic \
  %else
  --disable-rubyinterp \
  %endif
  %if %{withlua}
  --enable-luainterp=dynamic \
  %else
  --disable-luainterp \
  %endif
  %if %{with libsodium_crypt}
  --enable-libsodium \
  %else
  --disable-libsodium \
  %endif
  --enable-fail-if-missing --enable-canberra

%make_build
cp vim gvim
make clean
%endif

%configure CFLAGS="${CFLAGS} -DSYS_VIMRC_FILE='\"/etc/vimrc\"'" \
 --prefix=%{_prefix} --with-features=huge --enable-python3interp=dynamic \
 --enable-perlinterp=dynamic --disable-tclinterp --with-x=no \
 --enable-gui=no --exec-prefix=%{_prefix} --enable-multibyte --enable-cscope --with-modified-by="<os@lists.openanolis.cn>" \
 --with-tlib=ncurses --with-compiledby="<os@lists.openanolis.cn>" \
%if %{withnetbeans}
  --enable-netbeans \
%else
  --disable-netbeans \
%endif
%if %{WITH_SELINUX}
  --enable-selinux \
%else
  --disable-selinux \
%endif
%if %{withruby}
  --enable-rubyinterp=dynamic \
%else
  --disable-rubyinterp \
%endif
%if %{withlua}
  --enable-luainterp=dynamic \
%else
  --disable-luainterp \
%endif
%if %{with libsodium_crypt}
  --enable-libsodium \
%else
  --disable-libsodium \
%endif
  --enable-fail-if-missing \
  --disable-canberra

%make_build
cp %{name} enhanced-vim

%install
mkdir -p %{buildroot}/%{_bindir}
mkdir -p %{buildroot}/%{data_dir}/vimfiles/{after,autoload,colors,compiler,doc,ftdetect,ftplugin,indent,keymap,lang,plugin,print,spell,syntax,tutor}
mkdir -p %{buildroot}/%{data_dir}/vimfiles/after/{autoload,colors,compiler,doc,ftdetect,ftplugin,indent,keymap,lang,plugin,print,spell,syntax,tutor}
cp -f %{SOURCE7} %{buildroot}/%{data_dir}/vimfiles/template.spec
cp runtime/doc/uganda.txt LICENSE

rm -f README*.info

cd src
%make_install BINDIR=%{_bindir} STRIP=/bin/true
rm -f %{buildroot}%{_bindir}/{vim,view}
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/{16x16,32x32,48x48,64x64}/apps
mkdir -p %{buildroot}%{_libexecdir}
install -m755 minimal-vim %{buildroot}%{_libexecdir}/vi
install -m755 enhanced-vim %{buildroot}%{_bindir}/vim
install -m755 %{SOURCE12} %{buildroot}%{_bindir}/view
install -m755 %{SOURCE13} %{buildroot}%{_bindir}/vi

%if %{with gui}
make installgtutorbin  DESTDIR=%{buildroot} BINDIR=%{_bindir}
install -m755 gvim %{buildroot}%{_bindir}/gvim
install -p -m644 %{SOURCE3} %{buildroot}%{_datadir}/icons/hicolor/16x16/apps/gvim.png
install -p -m644 %{SOURCE4} %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/gvim.png
install -p -m644 %{SOURCE5} %{buildroot}%{_datadir}/icons/hicolor/48x48/apps/gvim.png
install -p -m644 %{SOURCE6} %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/gvim.png

mkdir -p $RPM_BUILD_ROOT%{_datadir}/metainfo
cat > $RPM_BUILD_ROOT%{_datadir}/metainfo/gvim.appdata.xml <<EOF
<?xml version="1.0" encoding="UTF-8"?>
<!-- Copyright 2014 Richard Hughes <richard@hughsie.com> -->
<!--
EmailAddress: Bram@moolenaar.net>
SentUpstream: 2014-05-22
-->
<application>
  <id type="desktop">gvim.desktop</id>
  <metadata_license>CC0-1.0</metadata_license>
  <project_license>Vim</project_license>
  <description>
    <p>
     Vim is a greatly improved version of the good old UNIX editor Vi.
     Many new features have been added: multi-level undo, syntax highlighting,
     command line history, on-line help, spell checking, filename completion,
     block operations, script language, etc. There is also a Graphical User
     Interface (GUI) available. Still, Vi compatibility is maintained, those
     who have Vi "in the fingers" will feel at home. See runtime/doc/vi_diff.txt
     for differences with Vi.
    </p>
    <p>
     Vim is very useful for editing programs and other plain text files.
     All commands are given with normal keyboard characters, so those who can
     type with ten fingers can work very fast. Additionally, function keys can
     be mapped to commands by the user, and the mouse can be used.
    </p>
  </description>
  <screenshots>
    <screenshot type="default">
      <image>https://raw.githubusercontent.com/zdohnal/vim/zdohnal-screenshot/gvim16_9.png</image>
    </screenshot>
  </screenshots>
  <url type="homepage">http://www.vim.org/</url>
</application>
EOF

appstream-util validate-relax --nonet %{buildroot}/%{_datadir}/metainfo/*.appdata.xml

for i in gvim.1 gex.1 gview.1 vimx.1; do 
  echo ".so man1/vim.1" > %{buildroot}/%{_mandir}/man1/$i
done
echo ".so man1/vimdiff.1" > %{buildroot}/%{_mandir}/man1/gvimdiff.1
echo ".so man1/vimtutor.1" > %{buildroot}/%{_mandir}/man1/gvimtutor.1
%else
rm %{buildroot}/%{_mandir}/man1/evim.*
rm %{buildroot}/%{_datadir}/applications/{vim,gvim}.desktop
rm %{buildroot}/%{_datadir}/icons/{hicolor,locolor}/*/apps/gvim.png
%endif

( cd %{buildroot}
  ln -s -f %{_libexecdir}/vi .%{_bindir}/rview
  ln -s -f %{_libexecdir}/vi .%{_bindir}/ex
  ln -s -f vim .%{_bindir}/vimdiff
  ln -s -f %{_libexecdir}/vi .%{_bindir}/rvi
  ln -s -f vim .%{_bindir}/rvim
  perl -pi -e "s,%{buildroot},," .%{_mandir}/man1/vim.1 .%{_mandir}/man1/vimtutor.1
  rm -f .%{_mandir}/man1/rvim.1
  cp -p .%{_mandir}/man1/vim.1 .%{_mandir}/man1/vi.1
  ln -s -f vi.1 .%{_mandir}/man1/ex.1
  ln -s -f vi.1 .%{_mandir}/man1/view.1
  ln -s -f vim.1 .%{_mandir}/man1/vimdiff.1
  ln -s -f vi.1 .%{_mandir}/man1/rvi.1
  ln -s -f vi.1 .%{_mandir}/man1/rview.1

%if %{with gui}
  ln -s -f gvim ./%{_bindir}/evim
  ln -s -f gvim ./%{_bindir}/gvimdiff
  ln -s -f gvim ./%{_bindir}/vimx
  ln -s -f gvim ./%{_bindir}/gex
  ln -s -f gvim ./%{_bindir}/gview

  %if %{desktop_file}
    desktop-file-install --dir %{buildroot}/%{_datadir}/applications %{buildroot}/%{_datadir}/applications/gvim.desktop
  %else
    mkdir -p ./%{_sysconfdir}/X11/applnk/Applications
    cp %{buildroot}/%{_datadir}/applications/gvim.desktop \
    	./%{_sysconfdir}/X11/applnk/Applications/gvim.desktop
  %endif

%endif

  ( cd ./%{data_vimdir}/lang; ln -s -f menu_ja_jp.ujis.vim menu_ja_jp.eucjp.vim )
)

pushd %{buildroot}/%{data_vimdir}/tutor
mkdir conv
   iconv -f UTF8 -t UTF8 tutor.ja.utf-8 > conv/tutor.ja.utf-8
   iconv -f CP1252 -t UTF8 tutor.ca > conv/tutor.ca
   iconv -f ISO-8859-2 -t UTF8 tutor.pl > conv/tutor.pl
   iconv -f ISO-8859-2 -t UTF8 tutor.sk > conv/tutor.sk
   iconv -f CP1252 -t UTF8 tutor.fr > conv/tutor.fr
   iconv -f CP1252 -t UTF8 tutor.es > conv/tutor.es
   iconv -f CP1252 -t UTF8 tutor.de > conv/tutor.de
   iconv -f UTF8 -t UTF8 tutor.ko.utf-8 > conv/tutor.ko.utf-8
   iconv -f CP1252 -t UTF8 tutor.no > conv/tutor.no
   iconv -f KOI8R -t UTF8 tutor.ru > conv/tutor.ru
   iconv -f CP1252 -t UTF8 tutor.sv > conv/tutor.sv
   iconv -f CP1252 -t UTF8 tutor.it > conv/tutor.it
   mv -f tutor.ja.euc tutor.ja.sjis tutor.ko.euc tutor.pl.cp1250 tutor.zh.big5 tutor.ru.cp1251 tutor.zh.euc tutor.sr.cp1250 tutor.sr.utf-8 conv/
   rm -f tutor.ca tutor.de tutor.es tutor.fr tutor.gr tutor.it tutor.ja.utf-8 tutor.ko.utf-8 tutor.no tutor.pl tutor.sk tutor.ru tutor.sv
mv -f conv/* .
rmdir conv
popd

chmod 644 %{buildroot}/%{data_vimdir}/doc/vim2html.pl \
 %{buildroot}/%{data_vimdir}/tools/*.pl \
 %{buildroot}/%{data_vimdir}/tools/vim132
chmod 644 ../runtime/doc/vim2html.pl

mkdir -p %{buildroot}%{_sysconfdir}
install -p -m644 %{SOURCE1} %{buildroot}%{_sysconfdir}/virc
install -p -m644 %{SOURCE2} %{buildroot}%{_sysconfdir}/vimrc

%if %{with default_editor}
mkdir -p %{buildroot}/%{_sysconfdir}/profile.d
install -p -m644 %{SOURCE9} %{buildroot}/%{_sysconfdir}/profile.d/vim-default-editor.sh
install -p -m644 %{SOURCE10} %{buildroot}/%{_sysconfdir}/profile.d/vim-default-editor.csh
mkdir -p %{buildroot}/%{_datadir}/fish/vendor_conf.d/
install -p -m644 %{SOURCE11} %{buildroot}/%{_datadir}/fish/vendor_conf.d/vim-default-editor.fish
mkdir -p %{buildroot}/%{_datadir}/fish/vendor_functions.d/
%endif

mkdir -p %{buildroot}%{_rpmconfigdir}/macros.d/
install -p -m644 %{SOURCE8} %{buildroot}%{_rpmconfigdir}/macros.d/

(cd ../runtime; %{__rm} -rf doc; ln -svf ../../vim/%{vimdir}/doc docs;) 
rm -f %{buildroot}/%{_datadir}/vim/%{vimdir}/macros/maze/maze*.c
rm -rf %{buildroot}/%{_datadir}/vim/%{vimdir}/tools
rm -rf %{buildroot}/%{_datadir}/vim/%{vimdir}/doc/vim2html.pl
rm -f %{buildroot}/%{_datadir}/vim/%{vimdir}/tutor/tutor.gr.utf-8~

for i in pl.ISO8859-2 it.ISO8859-1 ru.KOI8-R fr.ISO8859-1 da.ISO8859-1 de.ISO8859-1 tr.ISO8859-9; do
  rm -rf %{buildroot}/%{_mandir}/$i
done

mv %{buildroot}/%{_mandir}/ru.UTF-8 %{buildroot}/%{_mandir}/ru

for i in fr.UTF-8 it.UTF-8 pl.UTF-8 da.UTF-8 de.UTF-8 tr.UTF-8; do
  rm -rf %{buildroot}/%{_mandir}/$i
done

echo ".so man1/vim.1" > %{buildroot}/%{_mandir}/man1/rvim.1

mkdir -p %{buildroot}/%{_mandir}/man5
echo ".so man1/vim.1" > %{buildroot}/%{_mandir}/man5/vimrc.5
echo ".so man1/vi.1" > %{buildroot}/%{_mandir}/man5/virc.5
touch %{buildroot}/%{data_dir}/vimfiles/doc/tags

%generate_compatibility_deps


%transfiletriggerin common -- %{data_dir}/vimfiles/doc
%{_bindir}/vim -c ":helptags %{data_dir}/vimfiles/doc" -c :q &> /dev/null || :

%transfiletriggerpostun common -- %{data_dir}/vimfiles/doc
> %{data_dir}/vimfiles/doc/tags || :
%{_bindir}/vim -c ":helptags %{data_dir}/vimfiles/doc" -c :q &> /dev/null || :

%files common
%config(noreplace) %{_sysconfdir}/vimrc
%doc runtime/docs
%{data_vimdir}/colors
%{data_vimdir}/compiler
%{data_vimdir}/pack
%{data_vimdir}/doc
%{data_vimdir}/*.vim
%exclude %{data_vimdir}/defaults.vim
%{data_vimdir}/ftplugin
%{data_vimdir}/indent
%{data_vimdir}/keymap
%{data_vimdir}/lang/*.vim
%{data_vimdir}/lang/*.txt
%{data_vimdir}/autoload
%dir %{data_vimdir}/lang
%{data_vimdir}/macros
%{data_vimdir}/plugin
%{data_vimdir}/print
%{data_vimdir}/syntax
%{data_vimdir}/tutor
%{data_vimdir}/import/dist/*.vim

%if ! %{withvimspell}
%{data_vimdir}/spell
%endif

%lang(af) %{data_vimdir}/lang/af
%lang(ca) %{data_vimdir}/lang/ca
%lang(cs) %{data_vimdir}/lang/cs
%lang(cs.cp1250) %{data_vimdir}/lang/cs.cp1250
%lang(da) %{data_vimdir}/lang/da
%lang(de) %{data_vimdir}/lang/de
%lang(en_GB) %{data_vimdir}/lang/en_GB
%lang(eo) %{data_vimdir}/lang/eo
%lang(es) %{data_vimdir}/lang/es
%lang(fi) %{data_vimdir}/lang/fi
%lang(fr) %{data_vimdir}/lang/fr
%lang(ga) %{data_vimdir}/lang/ga
%lang(it) %{data_vimdir}/lang/it
%lang(ja) %{data_vimdir}/lang/ja
%lang(ja.euc-jp) %{data_vimdir}/lang/ja.euc-jp
%lang(ja.sjis) %{data_vimdir}/lang/ja.sjis
%lang(ko) %{data_vimdir}/lang/ko
%lang(ko) %{data_vimdir}/lang/ko.UTF-8
%lang(lv) %{data_vimdir}/lang/lv
%lang(nb) %{data_vimdir}/lang/nb
%lang(nl) %{data_vimdir}/lang/nl
%lang(no) %{data_vimdir}/lang/no
%lang(pl) %{data_vimdir}/lang/pl
%lang(pl.UTF-8) %{data_vimdir}/lang/pl.UTF-8
%lang(pl.cp1250) %{data_vimdir}/lang/pl.cp1250
%lang(pt_BR) %{data_vimdir}/lang/pt_BR
%lang(ru) %{data_vimdir}/lang/ru
%lang(ru.cp1251) %{data_vimdir}/lang/ru.cp1251
%lang(sk) %{data_vimdir}/lang/sk
%lang(sk.cp1250) %{data_vimdir}/lang/sk.cp1250
%lang(sr) %{data_vimdir}/lang/sr
%lang(sv) %{data_vimdir}/lang/sv
%lang(tr) %{data_vimdir}/lang/tr
%lang(uk) %{data_vimdir}/lang/uk
%lang(uk.cp1251) %{data_vimdir}/lang/uk.cp1251
%lang(vi) %{data_vimdir}/lang/vi
%lang(zh_CN) %{data_vimdir}/lang/zh_CN
%lang(zh_CN.cp936) %{data_vimdir}/lang/zh_CN.cp936
%lang(zh_TW) %{data_vimdir}/lang/zh_TW
%lang(zh_CN.UTF-8) %{data_vimdir}/lang/zh_CN.UTF-8
%lang(zh_TW.UTF-8) %{data_vimdir}/lang/zh_TW.UTF-8
/%{_bindir}/xxd
%{_mandir}/man1/rvim.*
%{_mandir}/man1/vim.*
%{_mandir}/man1/vimdiff.*
%{_mandir}/man1/vimtutor.*
%{_mandir}/man1/xxd.*
%{_mandir}/man5/vimrc.*

%if %{with gui}
%{_mandir}/man1/gex.*
%{_mandir}/man1/gview.*
%{_mandir}/man1/gvim*
%{_mandir}/man1/vimx.*
%endif

%lang(fr) %{_mandir}/fr/man1/*
%lang(da) %{_mandir}/da/man1/*
%lang(de) %{_mandir}/de/man1/*
%lang(it) %{_mandir}/it/man1/*
%lang(ja) %{_mandir}/ja/man1/*
%lang(pl) %{_mandir}/pl/man1/*
%lang(ru) %{_mandir}/ru/man1/*
%lang(tr) %{_mandir}/tr/man1/*

%files doc
%doc README*

%if %{withvimspell}
%files spell
%dir %{data_vimdir}/spell
%{data_dir}/vim70/spell/cleanadd.vim
%lang(af) %{data_vimdir}/spell/af.*
%lang(am) %{data_vimdir}/spell/am.*
%lang(bg) %{data_vimdir}/spell/bg.*
%lang(ca) %{data_vimdir}/spell/ca.*
%lang(cs) %{data_vimdir}/spell/cs.*
%lang(cy) %{data_vimdir}/spell/cy.*
%lang(da) %{data_vimdir}/spell/da.*
%lang(de) %{data_vimdir}/spell/de.*
%lang(el) %{data_vimdir}/spell/el.*
%lang(en) %{data_vimdir}/spell/en.*
%lang(eo) %{data_vimdir}/spell/eo.*
%lang(es) %{data_vimdir}/spell/es.*
%lang(fo) %{data_vimdir}/spell/fo.*
%lang(fr) %{data_vimdir}/spell/fr.*
%lang(ga) %{data_vimdir}/spell/ga.*
%lang(gd) %{data_vimdir}/spell/gd.*
%lang(gl) %{data_vimdir}/spell/gl.*
%lang(he) %{data_vimdir}/spell/he.*
%lang(hr) %{data_vimdir}/spell/hr.*
%lang(hu) %{data_vimdir}/spell/hu.*
%lang(id) %{data_vimdir}/spell/id.*
%lang(it) %{data_vimdir}/spell/it.*
%lang(ku) %{data_vimdir}/spell/ku.*
%lang(la) %{data_vimdir}/spell/la.*
%lang(lt) %{data_vimdir}/spell/lt.*
%lang(lv) %{data_vimdir}/spell/lv.*
%lang(mg) %{data_vimdir}/spell/mg.*
%lang(mi) %{data_vimdir}/spell/mi.*
%lang(ms) %{data_vimdir}/spell/ms.*
%lang(nb) %{data_vimdir}/spell/nb.*
%lang(nl) %{data_vimdir}/spell/nl.*
%lang(nn) %{data_vimdir}/spell/nn.*
%lang(ny) %{data_vimdir}/spell/ny.*
%lang(pl) %{data_vimdir}/spell/pl.*
%lang(pt) %{data_vimdir}/spell/pt.*
%lang(ro) %{data_vimdir}/spell/ro.*
%lang(ru) %{data_vimdir}/spell/ru.*
%lang(rw) %{data_vimdir}/spell/rw.*
%lang(sk) %{data_vimdir}/spell/sk.*
%lang(sl) %{data_vimdir}/spell/sl.*
%lang(sr) %{data_vimdir}/spell/sr.*
%lang(sv) %{data_vimdir}/spell/sv.*
%lang(sw) %{data_vimdir}/spell/sw.*
%lang(tet) %{data_vimdir}/spell/tet.*
%lang(th) %{data_vimdir}/spell/th.*
%lang(tl) %{data_vimdir}/spell/tl.*
%lang(tn) %{data_vimdir}/spell/tn.*
%lang(uk) %{data_vimdir}/spell/uk.*
%lang(yi) %{data_vimdir}/spell/yi.*
%lang(yi-tr) %{data_vimdir}/spell/yi-tr.*
%lang(zu) %{data_vimdir}/spell/zu.*
%endif

%files minimal
%config(noreplace) %{_sysconfdir}/virc
%{_bindir}/ex
%{_bindir}/rvi
%{_bindir}/rview
%{_bindir}/vi
%{_bindir}/view
%{_libexecdir}/vi
%{_mandir}/man1/vi.*
%{_mandir}/man1/ex.*
%{_mandir}/man1/rvi.*
%{_mandir}/man1/rview.*
%{_mandir}/man1/view.*
%{_mandir}/man5/virc.*

%files enhanced
%{_bindir}/rvim
%{_bindir}/vim
%{_bindir}/vimdiff
%{_bindir}/vimtutor
%dir %{abidir}
%{abidir}/vim-option.list

%files filesystem
%{_rpmconfigdir}/macros.d/macros.vim
%dir %{data_dir}/vimfiles/after
%dir %{data_dir}/vimfiles/after/*
%dir %{data_dir}/vimfiles/autoload
%dir %{data_dir}/vimfiles/colors
%dir %{data_dir}/vimfiles/compiler
%dir %{data_dir}/vimfiles/doc
%ghost %{data_dir}/vimfiles/doc/tags
%dir %{data_dir}/vimfiles/ftdetect
%dir %{data_dir}/vimfiles/ftplugin
%dir %{data_dir}/vimfiles/indent
%dir %{data_dir}/vimfiles/keymap
%dir %{data_dir}/vimfiles/lang
%dir %{data_dir}/vimfiles/plugin
%dir %{data_dir}/vimfiles/print
%dir %{data_dir}/vimfiles/spell
%dir %{data_dir}/vimfiles/syntax
%dir %{data_dir}/vimfiles/tutor

%if %{with gui}
%files X11
  %if %{desktop_file}
%{_datadir}/metainfo/*.appdata.xml
/%{_datadir}/applications/*
%exclude /%{_datadir}/applications/vim.desktop
  %else
/%{_sysconfdir}/X11/applnk/*/gvim.desktop
  %endif
%{_bindir}/gvimtutor
%{_bindir}/gvim
%{_bindir}/gvimdiff
%{_bindir}/gview
%{_bindir}/gex
%{_bindir}/vimtutor
%{_bindir}/vimx
%{_bindir}/evim
%{_mandir}/man1/evim.*
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/*
%dir %{_datadir}/icons/hicolor/*/apps
%{_datadir}/icons/hicolor/*/apps/*
%dir %{_datadir}/icons/locolor
%dir %{_datadir}/icons/locolor/*
%dir %{_datadir}/icons/locolor/*/apps
%{_datadir}/icons/locolor/*/apps/*
%{abidir}/gvim-option.list
%endif

%files data
%license LICENSE
%dir %{data_dir}
%dir %{data_dir}/%{vimdir}
%{data_vimdir}/defaults.vim
%dir %{data_dir}/vimfiles
%{data_dir}/vimfiles/template.spec

%if %{with default_editor}
%files default-editor
%dir %{_datadir}/fish/vendor_conf.d
%{_datadir}/fish/vendor_conf.d/vim-default-editor.fish
%config(noreplace) %{_sysconfdir}/profile.d/vim-default-editor.*
%endif

%changelog
* Thu Aug 29 2024 wangce <wangce@uniontech.com> - 3:9.0.2092-3
- fix fix CVE-2024-22667

* Tue Wed 27 2024 houfangdong <houfangdong@loongson.cn> - 3:9.0.2092-2
- New patchlevel 9.0.2092

* Tue Nov 23 2023 Funda Wang <fundawang@yeah.net> - 2:9.0.2122-1
- New patchlevel 9.0.2122

* Mon Nov 06 2023 Funda Wang <fundawang@yeah.net> - 2:9.0.2092-1
- New patchlevel 9.0.2092

* Sun Oct 15 2023 Funda Wang <fundawang@yeah.net> - 2:9.0.2026-1
- New patchlevel 9.0.2026

* Mon Jul 10 2023 Funda Wang <fundawang@yeah.net> - 2:9.0.1677-1
- New patchlevel 9.0.1677

* Sun May 21 2023 Funda Wang <fundawang@yeah.net> - 2:9.0.1572-1
- New patchlevel 9.0.1572
- Move patchlevel into version field as other distros

* Thu May 04 2023 Chunnmei Xu <xuchunmei@linux.alibaba.com> - 2:9.0-6
- generate_compatibility_deps in install stage

* Wed Apr 12 2023 Heng Qi <hengqi@linux.alibaba.com> - 2:9.0-5
- Refactor the spec file

* Tue Jan 31 2023 Funda Wang <fundawang@yeah.net> - 2:9.0-4
- New patchlevel 9.0.1267

* Fri Dec 30 2022 Funda Wang <fundawang@yeah.net> - 2:9.0-3
- New patchlevel 9.0.1108

* Tue Dec 6 2022 Funda Wang <fundawang@yeah.net> - 2:9.0-2
- Rebuild with zstd compression of man pages

* Wed Aug 31 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2:9.0-1
- update vim to 9.0

* Mon Mar 21 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2:8.2-3
- fix copy and paste

* Mon Mar 21 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2:8.2-2
- optimise Conflicts version

* Wed Mar  9 2022 Liwei Ge <liwei.glw@linux.alibaba.com> - 2:8.2-1
- Init version from upstream v8.2
- disbale ruby
